GitRefStore

Struct GitRefStore 

pub struct GitRefStore<'r> { /* private fields */ }
Git-backed implementation of RefReader and RefWriter.

References are Git refs. resolve_ref returns the commit OID bytes the ref points to. update_ref creates or updates a ref to point at a commit whose tree contains the given data.

Usage:

use auths_infra_git::{GitRepo, GitRefStore};
use auths_core::ports::storage::RefReader;

let repo = GitRepo::open("/path/to/repo")?;
let store = GitRefStore::new(&repo);
let oid_bytes = store.resolve_ref("refs/auths/registry")?;

Implementations

Source

impl<'r> GitRefStore<'r>

pub fn new(repo: &'r GitRepo) -> Self